@@ -45,13 +45,13 @@ if(!is.null(x$fn) ) {if(x$fn == "principal") {cat("Principal Components Analysis
           		 }  
          }    #end of sort 		 
     #they are now sorted, don't print the small loadings if cut > 0 
-                if(max(abs(load) > 1.0) && !covar) cat('\n Warning: A Heywood case was detected. \n')
+               # if(max(abs(load) > 1.0) && !covar) cat('\n Warning: A Heywood case was detected. \n')
           	ncol <- dim(loads)[2]-2
           	rloads <- round(loads,digits)
 	    	fx <- format(rloads,digits=digits)
 	    	nc <- nchar(fx[1,3], type = "c")
 	    	 fx.1 <- fx[,1,drop=FALSE]    #drop = FALSE  preserves the rownames for single factors
-	    	 fx.2 <- fx[,3:(2+ncol)]
+	    	 fx.2 <- fx[,3:(2+ncol),drop=FALSE]
 	    	 load.2 <- as.matrix(loads[,3:(ncol+2)])
          	fx.2[abs(load.2) < cut] <- paste(rep(" ", nc), collapse = "")
          if(sort) {	fx <- data.frame(V=fx.1,fx.2)
@@ -168,7 +168,7 @@ if(!is.null(x$fn) ) {if(x$fn == "principal") {cat("Principal Components Analysis
 if ((!is.null(x$fn)) && (x$fn != "principal")) {
 if(!is.null(x$R2)) { stats.df <- t(data.frame(sqrt(x$R2),x$R2,2*x$R2 -1))
 
- rownames(stats.df) <- c("Correlation of scores with factors  ","Multiple R square of scores with factors ","Minimum correlation of possible factor scores ")
+ rownames(stats.df) <- c("Correlation of (regression) scores with factors  ","Multiple R square of scores with factors ","Minimum correlation of possible factor scores ")
          colnames(stats.df) <- colnames(x$loadings)
  } else {stats.df <- NULL}
  badFlag <- FALSE
@@ -183,13 +183,19 @@ if(!is.null(x$R2)) { stats.df <- t(data.frame(sqrt(x$R2),x$R2,2*x$R2 -1))
 	
 	 if(!is.null(stats.df)) { cat("\nMeasures of factor score adequacy             \n")
       print(round(stats.df,digits))}
-
-	if(!is.null(x$stats$R2) && !badFlag) {cat("\nMeasures of factor score adequacy             ",colnames(x$loadings)  )
-	cat("\nCorrelation of scores with factors           ",round(sqrt(x$R2),digits))
-	cat("\nMultiple R square of scores with factors      " ,round(x$R2,digits))
-	  cat("\nMinimum correlation of factor score estimates ", round(2*x$R2 -1,digits)) }
+#why do we have this next part?  It seems redundant
+# 	 if(is.null(x$method)) x$method <- ""
+# 	 if(is.null(x$R2.scores))  x$R2.scores <- NA
+#     if(any(is.na(x$R2.scores)) | any(x$R2 != x$R2.scores))  {stats.df <- t(data.frame(sqrt(x$R2.scores),x$R2.scores,2* x$R2.scores -1))
+#     cat("\n Factor scores estimated using the ", x$method, " method  have correlations of \n")
+#      rownames(stats.df) <- c("Correlation of scores with factors  ","Multiple R square of scores with factors ","Minimum correlation of possible factor scores ")
+#   #  colnames(stats.df) <- colnames(x$loadings)
+#      print(round(stats.df,digits))
+#     }
+   
 	  }
  }
+
  result <- list(Vaccounted=varex)
  invisible(result) 
 } 
