@@ -18,11 +18,11 @@ if(!is.null(x$cfit.1)) {
   vss.max <- round(max(x$cfit.2) ,digits) 
  cat(vss.max," with " ,which.max(x$cfit.2), " factors\n") 
  cat("\nThe Velicer MAP achieves a minimum of ")
- vss.map <- round(min(x$map) ,digits) 
+ vss.map <- round(min(x$map,na.rm=TRUE) ,digits) 
  cat(vss.map," with " ,which.min(x$map), " factors ") 
- bic.min <- round(min(x$vss.stats[,"BIC"]),digits)
+ bic.min <- round(min(x$vss.stats[,"BIC"],na.rm=TRUE),digits)
  cat("\nBIC achieves a minimum of ", bic.min," with ", which.min(x$vss.stats[,"BIC"])," factors\n")
- sabic.min <- round(min(x$vss.stats[,"SABIC"]),digits)
+ sabic.min <- round(min(x$vss.stats[,"SABIC"],na.rm=TRUE),digits)
  cat("Sample Size adjusted BIC achieves a minimum of ", sabic.min," with ", which.min(x$vss.stats[,"SABIC"])," factors\n")
  # cat("\nVelicer MAP\n")
   #    print(round(x$map,digits))
@@ -39,13 +39,13 @@ if(!is.null(x$cfit.1)) {
  cat("Call: ")
  print(x$call)
  cat("VSS complexity 1 achieves a maximimum of ")
- vss.max <- round(max(x$vss.stats$cfit.1) ,digits) 
+ vss.max <- round(max(x$vss.stats$cfit.1,na.rm=TRUE) ,digits) 
  wh.max <- which.max(x$vss.stats$cfit.1)
  if(wh.max !=first.max(x$vss.stats$cfit.1)) {cat("Although the vss.max shows ",wh.max," factors, it is probably more reasonable to think about ",first.max(x$vss.stats$cfit.1), " factors\n")} else {
  cat(vss.max," with " ,wh.max, " factors\n") }
 
  cat("VSS complexity 2 achieves a maximimum of ")
-  vss.max <- round(max(x$vss.stats$cfit.2) ,digits) 
+  vss.max <- round(max(x$vss.stats$cfit.2,na.rm=TRUE) ,digits) 
  cat(vss.max," with " ,which.max(x$vss.stats$cfit.2), " factors\n") 
  cat("The Velicer MAP achieves a minimum of ")
  vss.map <- round(min(x$map,na.rm=TRUE) ,digits) 
